;; Generated package description from csharp-mode.el  -*- no-byte-compile: t -*-
(define-package "csharp-mode" "2.0.0.0.20221126.200508" "C# mode derived mode" '((emacs "26.1")) :commit "d8b058c9e9d0429ea7e81d121ce19b064bd7e0f5" :authors '(("Theodor Thornhill" . "theo@thornhill.no")) :maintainer '("Jostein Kjønigsen" . "jostein@gmail.com") :keywords '("c#" "languages" "oop" "mode") :url "https://github.com/emacs-csharp/csharp-mode")
